# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKSpatialObjectsPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkImageSpatialObjectPython
else:
    import _itkImageSpatialObjectPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkPointPython
import itk.itkFixedArrayPython
import itk.pyBasePython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.itkVectorPython
import itk.vnl_vector_refPython
import itk.itkInterpolateImageFunctionPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkContinuousIndexPython
import itk.itkIndexPython
import itk.itkSizePython
import itk.itkOffsetPython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkImageFunctionBasePython
import itk.itkImagePython
import itk.itkImageRegionPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkFunctionBasePython
import itk.itkArrayPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkSpatialObjectBasePython
import itk.itkBoundingBoxPython
import itk.itkVectorContainerPython
import itk.itkMapContainerPython
import itk.itkAffineTransformPython
import itk.itkTransformBasePython
import itk.itkOptimizerParametersPython
import itk.itkDiffusionTensor3DPython
import itk.itkVariableLengthVectorPython
import itk.itkArray2DPython
import itk.itkMatrixOffsetTransformBasePython
import itk.itkSpatialObjectPropertyPython
class listitkImageSpatialObject2UC_Pointer(collections.abc.MutableSequence if _swig_python_version_info >= (3, 3) else collections.MutableSequence):
    r"""Proxy of C++ std::list< itkImageSpatialObject2UC_Pointer > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        r"""iterator(self) -> SwigPyIterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        r"""__nonzero__(self) -> bool"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer___nonzero__(self)

    def __bool__(self):
        r"""__bool__(self) -> bool"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer___bool__(self)

    def __len__(self):
        r"""__len__(self) -> std::list< itkImageSpatialObject2UC_Pointer >::size_type"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer___len__(self)

    def __getslice__(self, i, j):
        r"""
        __getslice__(self, i, j) -> listitkImageSpatialObject2UC_Pointer

        Parameters
        ----------
        i: std::list< itkImageSpatialObject2UC_Pointer >::difference_type
        j: std::list< itkImageSpatialObject2UC_Pointer >::difference_type

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer___getslice__(self, i, j)

    def __setslice__(self, *args):
        r"""
        __setslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject2UC_Pointer >::difference_type
        j: std::list< itkImageSpatialObject2UC_Pointer >::difference_type

        __setslice__(self, i, j, v)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject2UC_Pointer >::difference_type
        j: std::list< itkImageSpatialObject2UC_Pointer >::difference_type
        v: std::list< itkImageSpatialObject2UC_Pointer,std::allocator< itkImageSpatialObject2UC_Pointer > > const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer___setslice__(self, *args)

    def __delslice__(self, i, j):
        r"""
        __delslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject2UC_Pointer >::difference_type
        j: std::list< itkImageSpatialObject2UC_Pointer >::difference_type

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer___delslice__(self, i, j)

    def __delitem__(self, *args):
        r"""
        __delitem__(self, i)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject2UC_Pointer >::difference_type

        __delitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer___delitem__(self, *args)

    def __getitem__(self, *args):
        r"""
        __getitem__(self, slice) -> listitkImageSpatialObject2UC_Pointer

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __getitem__(self, i) -> std::list< itkImageSpatialObject2UC_Pointer >::value_type const &

        Parameters
        ----------
        i: std::list< itkImageSpatialObject2UC_Pointer >::difference_type

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer___getitem__(self, *args)

    def __setitem__(self, *args):
        r"""
        __setitem__(self, slice, v)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *
        v: std::list< itkImageSpatialObject2UC_Pointer,std::allocator< itkImageSpatialObject2UC_Pointer > > const &

        __setitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __setitem__(self, i, x)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject2UC_Pointer >::difference_type
        x: std::list< itkImageSpatialObject2UC_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer___setitem__(self, *args)

    def pop(self):
        r"""pop(self) -> std::list< itkImageSpatialObject2UC_Pointer >::value_type"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer_pop(self)

    def append(self, x):
        r"""
        append(self, x)

        Parameters
        ----------
        x: std::list< itkImageSpatialObject2UC_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer_append(self, x)

    def empty(self):
        r"""empty(self) -> bool"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer_empty(self)

    def size(self):
        r"""size(self) -> std::list< itkImageSpatialObject2UC_Pointer >::size_type"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer_size(self)

    def swap(self, v):
        r"""
        swap(self, v)

        Parameters
        ----------
        v: std::list< itkImageSpatialObject2UC_Pointer > &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer_swap(self, v)

    def begin(self):
        r"""begin(self) -> std::list< itkImageSpatialObject2UC_Pointer >::iterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer_begin(self)

    def end(self):
        r"""end(self) -> std::list< itkImageSpatialObject2UC_Pointer >::iterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer_end(self)

    def rbegin(self):
        r"""rbegin(self) -> std::list< itkImageSpatialObject2UC_Pointer >::reverse_iterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer_rbegin(self)

    def rend(self):
        r"""rend(self) -> std::list< itkImageSpatialObject2UC_Pointer >::reverse_iterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer_rend(self)

    def clear(self):
        r"""clear(self)"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer_clear(self)

    def get_allocator(self):
        r"""get_allocator(self) -> std::list< itkImageSpatialObject2UC_Pointer >::allocator_type"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer_get_allocator(self)

    def pop_back(self):
        r"""pop_back(self)"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer_pop_back(self)

    def erase(self, *args):
        r"""
        erase(self, pos) -> std::list< itkImageSpatialObject2UC_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkImageSpatialObject2UC_Pointer >::iterator

        erase(self, first, last) -> std::list< itkImageSpatialObject2UC_Pointer >::iterator

        Parameters
        ----------
        first: std::list< itkImageSpatialObject2UC_Pointer >::iterator
        last: std::list< itkImageSpatialObject2UC_Pointer >::iterator

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer_erase(self, *args)

    def __init__(self, *args):
        r"""
        __init__(self) -> listitkImageSpatialObject2UC_Pointer
        __init__(self, other) -> listitkImageSpatialObject2UC_Pointer

        Parameters
        ----------
        other: std::list< itkImageSpatialObject2UC_Pointer > const &

        __init__(self, size) -> listitkImageSpatialObject2UC_Pointer

        Parameters
        ----------
        size: std::list< itkImageSpatialObject2UC_Pointer >::size_type

        __init__(self, size, value) -> listitkImageSpatialObject2UC_Pointer

        Parameters
        ----------
        size: std::list< itkImageSpatialObject2UC_Pointer >::size_type
        value: std::list< itkImageSpatialObject2UC_Pointer >::value_type const &

        """
        _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer_swiginit(self, _itkImageSpatialObjectPython.new_listitkImageSpatialObject2UC_Pointer(*args))

    def push_back(self, x):
        r"""
        push_back(self, x)

        Parameters
        ----------
        x: std::list< itkImageSpatialObject2UC_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer_push_back(self, x)

    def front(self):
        r"""front(self) -> std::list< itkImageSpatialObject2UC_Pointer >::value_type const &"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer_front(self)

    def back(self):
        r"""back(self) -> std::list< itkImageSpatialObject2UC_Pointer >::value_type const &"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer_back(self)

    def assign(self, n, x):
        r"""
        assign(self, n, x)

        Parameters
        ----------
        n: std::list< itkImageSpatialObject2UC_Pointer >::size_type
        x: std::list< itkImageSpatialObject2UC_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer_assign(self, n, x)

    def resize(self, *args):
        r"""
        resize(self, new_size)

        Parameters
        ----------
        new_size: std::list< itkImageSpatialObject2UC_Pointer >::size_type

        resize(self, new_size, x)

        Parameters
        ----------
        new_size: std::list< itkImageSpatialObject2UC_Pointer >::size_type
        x: std::list< itkImageSpatialObject2UC_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer_resize(self, *args)

    def insert(self, *args):
        r"""
        insert(self, pos, x) -> std::list< itkImageSpatialObject2UC_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkImageSpatialObject2UC_Pointer >::iterator
        x: std::list< itkImageSpatialObject2UC_Pointer >::value_type const &

        insert(self, pos, n, x)

        Parameters
        ----------
        pos: std::list< itkImageSpatialObject2UC_Pointer >::iterator
        n: std::list< itkImageSpatialObject2UC_Pointer >::size_type
        x: std::list< itkImageSpatialObject2UC_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer_insert(self, *args)

    def pop_front(self):
        r"""pop_front(self)"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer_pop_front(self)

    def push_front(self, x):
        r"""
        push_front(self, x)

        Parameters
        ----------
        x: std::list< itkImageSpatialObject2UC_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer_push_front(self, x)

    def reverse(self):
        r"""reverse(self)"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer_reverse(self)
    __swig_destroy__ = _itkImageSpatialObjectPython.delete_listitkImageSpatialObject2UC_Pointer

# Register listitkImageSpatialObject2UC_Pointer in _itkImageSpatialObjectPython:
_itkImageSpatialObjectPython.listitkImageSpatialObject2UC_Pointer_swigregister(listitkImageSpatialObject2UC_Pointer)
class listitkImageSpatialObject2SS_Pointer(collections.abc.MutableSequence if _swig_python_version_info >= (3, 3) else collections.MutableSequence):
    r"""Proxy of C++ std::list< itkImageSpatialObject2SS_Pointer > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        r"""iterator(self) -> SwigPyIterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        r"""__nonzero__(self) -> bool"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer___nonzero__(self)

    def __bool__(self):
        r"""__bool__(self) -> bool"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer___bool__(self)

    def __len__(self):
        r"""__len__(self) -> std::list< itkImageSpatialObject2SS_Pointer >::size_type"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer___len__(self)

    def __getslice__(self, i, j):
        r"""
        __getslice__(self, i, j) -> listitkImageSpatialObject2SS_Pointer

        Parameters
        ----------
        i: std::list< itkImageSpatialObject2SS_Pointer >::difference_type
        j: std::list< itkImageSpatialObject2SS_Pointer >::difference_type

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer___getslice__(self, i, j)

    def __setslice__(self, *args):
        r"""
        __setslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject2SS_Pointer >::difference_type
        j: std::list< itkImageSpatialObject2SS_Pointer >::difference_type

        __setslice__(self, i, j, v)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject2SS_Pointer >::difference_type
        j: std::list< itkImageSpatialObject2SS_Pointer >::difference_type
        v: std::list< itkImageSpatialObject2SS_Pointer,std::allocator< itkImageSpatialObject2SS_Pointer > > const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer___setslice__(self, *args)

    def __delslice__(self, i, j):
        r"""
        __delslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject2SS_Pointer >::difference_type
        j: std::list< itkImageSpatialObject2SS_Pointer >::difference_type

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer___delslice__(self, i, j)

    def __delitem__(self, *args):
        r"""
        __delitem__(self, i)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject2SS_Pointer >::difference_type

        __delitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer___delitem__(self, *args)

    def __getitem__(self, *args):
        r"""
        __getitem__(self, slice) -> listitkImageSpatialObject2SS_Pointer

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __getitem__(self, i) -> std::list< itkImageSpatialObject2SS_Pointer >::value_type const &

        Parameters
        ----------
        i: std::list< itkImageSpatialObject2SS_Pointer >::difference_type

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer___getitem__(self, *args)

    def __setitem__(self, *args):
        r"""
        __setitem__(self, slice, v)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *
        v: std::list< itkImageSpatialObject2SS_Pointer,std::allocator< itkImageSpatialObject2SS_Pointer > > const &

        __setitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __setitem__(self, i, x)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject2SS_Pointer >::difference_type
        x: std::list< itkImageSpatialObject2SS_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer___setitem__(self, *args)

    def pop(self):
        r"""pop(self) -> std::list< itkImageSpatialObject2SS_Pointer >::value_type"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer_pop(self)

    def append(self, x):
        r"""
        append(self, x)

        Parameters
        ----------
        x: std::list< itkImageSpatialObject2SS_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer_append(self, x)

    def empty(self):
        r"""empty(self) -> bool"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer_empty(self)

    def size(self):
        r"""size(self) -> std::list< itkImageSpatialObject2SS_Pointer >::size_type"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer_size(self)

    def swap(self, v):
        r"""
        swap(self, v)

        Parameters
        ----------
        v: std::list< itkImageSpatialObject2SS_Pointer > &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer_swap(self, v)

    def begin(self):
        r"""begin(self) -> std::list< itkImageSpatialObject2SS_Pointer >::iterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer_begin(self)

    def end(self):
        r"""end(self) -> std::list< itkImageSpatialObject2SS_Pointer >::iterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer_end(self)

    def rbegin(self):
        r"""rbegin(self) -> std::list< itkImageSpatialObject2SS_Pointer >::reverse_iterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer_rbegin(self)

    def rend(self):
        r"""rend(self) -> std::list< itkImageSpatialObject2SS_Pointer >::reverse_iterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer_rend(self)

    def clear(self):
        r"""clear(self)"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer_clear(self)

    def get_allocator(self):
        r"""get_allocator(self) -> std::list< itkImageSpatialObject2SS_Pointer >::allocator_type"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer_get_allocator(self)

    def pop_back(self):
        r"""pop_back(self)"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer_pop_back(self)

    def erase(self, *args):
        r"""
        erase(self, pos) -> std::list< itkImageSpatialObject2SS_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkImageSpatialObject2SS_Pointer >::iterator

        erase(self, first, last) -> std::list< itkImageSpatialObject2SS_Pointer >::iterator

        Parameters
        ----------
        first: std::list< itkImageSpatialObject2SS_Pointer >::iterator
        last: std::list< itkImageSpatialObject2SS_Pointer >::iterator

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer_erase(self, *args)

    def __init__(self, *args):
        r"""
        __init__(self) -> listitkImageSpatialObject2SS_Pointer
        __init__(self, other) -> listitkImageSpatialObject2SS_Pointer

        Parameters
        ----------
        other: std::list< itkImageSpatialObject2SS_Pointer > const &

        __init__(self, size) -> listitkImageSpatialObject2SS_Pointer

        Parameters
        ----------
        size: std::list< itkImageSpatialObject2SS_Pointer >::size_type

        __init__(self, size, value) -> listitkImageSpatialObject2SS_Pointer

        Parameters
        ----------
        size: std::list< itkImageSpatialObject2SS_Pointer >::size_type
        value: std::list< itkImageSpatialObject2SS_Pointer >::value_type const &

        """
        _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer_swiginit(self, _itkImageSpatialObjectPython.new_listitkImageSpatialObject2SS_Pointer(*args))

    def push_back(self, x):
        r"""
        push_back(self, x)

        Parameters
        ----------
        x: std::list< itkImageSpatialObject2SS_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer_push_back(self, x)

    def front(self):
        r"""front(self) -> std::list< itkImageSpatialObject2SS_Pointer >::value_type const &"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer_front(self)

    def back(self):
        r"""back(self) -> std::list< itkImageSpatialObject2SS_Pointer >::value_type const &"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer_back(self)

    def assign(self, n, x):
        r"""
        assign(self, n, x)

        Parameters
        ----------
        n: std::list< itkImageSpatialObject2SS_Pointer >::size_type
        x: std::list< itkImageSpatialObject2SS_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer_assign(self, n, x)

    def resize(self, *args):
        r"""
        resize(self, new_size)

        Parameters
        ----------
        new_size: std::list< itkImageSpatialObject2SS_Pointer >::size_type

        resize(self, new_size, x)

        Parameters
        ----------
        new_size: std::list< itkImageSpatialObject2SS_Pointer >::size_type
        x: std::list< itkImageSpatialObject2SS_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer_resize(self, *args)

    def insert(self, *args):
        r"""
        insert(self, pos, x) -> std::list< itkImageSpatialObject2SS_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkImageSpatialObject2SS_Pointer >::iterator
        x: std::list< itkImageSpatialObject2SS_Pointer >::value_type const &

        insert(self, pos, n, x)

        Parameters
        ----------
        pos: std::list< itkImageSpatialObject2SS_Pointer >::iterator
        n: std::list< itkImageSpatialObject2SS_Pointer >::size_type
        x: std::list< itkImageSpatialObject2SS_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer_insert(self, *args)

    def pop_front(self):
        r"""pop_front(self)"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer_pop_front(self)

    def push_front(self, x):
        r"""
        push_front(self, x)

        Parameters
        ----------
        x: std::list< itkImageSpatialObject2SS_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer_push_front(self, x)

    def reverse(self):
        r"""reverse(self)"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer_reverse(self)
    __swig_destroy__ = _itkImageSpatialObjectPython.delete_listitkImageSpatialObject2SS_Pointer

# Register listitkImageSpatialObject2SS_Pointer in _itkImageSpatialObjectPython:
_itkImageSpatialObjectPython.listitkImageSpatialObject2SS_Pointer_swigregister(listitkImageSpatialObject2SS_Pointer)
class listitkImageSpatialObject2F_Pointer(collections.abc.MutableSequence if _swig_python_version_info >= (3, 3) else collections.MutableSequence):
    r"""Proxy of C++ std::list< itkImageSpatialObject2F_Pointer > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        r"""iterator(self) -> SwigPyIterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        r"""__nonzero__(self) -> bool"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer___nonzero__(self)

    def __bool__(self):
        r"""__bool__(self) -> bool"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer___bool__(self)

    def __len__(self):
        r"""__len__(self) -> std::list< itkImageSpatialObject2F_Pointer >::size_type"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer___len__(self)

    def __getslice__(self, i, j):
        r"""
        __getslice__(self, i, j) -> listitkImageSpatialObject2F_Pointer

        Parameters
        ----------
        i: std::list< itkImageSpatialObject2F_Pointer >::difference_type
        j: std::list< itkImageSpatialObject2F_Pointer >::difference_type

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer___getslice__(self, i, j)

    def __setslice__(self, *args):
        r"""
        __setslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject2F_Pointer >::difference_type
        j: std::list< itkImageSpatialObject2F_Pointer >::difference_type

        __setslice__(self, i, j, v)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject2F_Pointer >::difference_type
        j: std::list< itkImageSpatialObject2F_Pointer >::difference_type
        v: std::list< itkImageSpatialObject2F_Pointer,std::allocator< itkImageSpatialObject2F_Pointer > > const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer___setslice__(self, *args)

    def __delslice__(self, i, j):
        r"""
        __delslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject2F_Pointer >::difference_type
        j: std::list< itkImageSpatialObject2F_Pointer >::difference_type

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer___delslice__(self, i, j)

    def __delitem__(self, *args):
        r"""
        __delitem__(self, i)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject2F_Pointer >::difference_type

        __delitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer___delitem__(self, *args)

    def __getitem__(self, *args):
        r"""
        __getitem__(self, slice) -> listitkImageSpatialObject2F_Pointer

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __getitem__(self, i) -> std::list< itkImageSpatialObject2F_Pointer >::value_type const &

        Parameters
        ----------
        i: std::list< itkImageSpatialObject2F_Pointer >::difference_type

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer___getitem__(self, *args)

    def __setitem__(self, *args):
        r"""
        __setitem__(self, slice, v)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *
        v: std::list< itkImageSpatialObject2F_Pointer,std::allocator< itkImageSpatialObject2F_Pointer > > const &

        __setitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __setitem__(self, i, x)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject2F_Pointer >::difference_type
        x: std::list< itkImageSpatialObject2F_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer___setitem__(self, *args)

    def pop(self):
        r"""pop(self) -> std::list< itkImageSpatialObject2F_Pointer >::value_type"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer_pop(self)

    def append(self, x):
        r"""
        append(self, x)

        Parameters
        ----------
        x: std::list< itkImageSpatialObject2F_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer_append(self, x)

    def empty(self):
        r"""empty(self) -> bool"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer_empty(self)

    def size(self):
        r"""size(self) -> std::list< itkImageSpatialObject2F_Pointer >::size_type"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer_size(self)

    def swap(self, v):
        r"""
        swap(self, v)

        Parameters
        ----------
        v: std::list< itkImageSpatialObject2F_Pointer > &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer_swap(self, v)

    def begin(self):
        r"""begin(self) -> std::list< itkImageSpatialObject2F_Pointer >::iterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer_begin(self)

    def end(self):
        r"""end(self) -> std::list< itkImageSpatialObject2F_Pointer >::iterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer_end(self)

    def rbegin(self):
        r"""rbegin(self) -> std::list< itkImageSpatialObject2F_Pointer >::reverse_iterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer_rbegin(self)

    def rend(self):
        r"""rend(self) -> std::list< itkImageSpatialObject2F_Pointer >::reverse_iterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer_rend(self)

    def clear(self):
        r"""clear(self)"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer_clear(self)

    def get_allocator(self):
        r"""get_allocator(self) -> std::list< itkImageSpatialObject2F_Pointer >::allocator_type"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer_get_allocator(self)

    def pop_back(self):
        r"""pop_back(self)"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer_pop_back(self)

    def erase(self, *args):
        r"""
        erase(self, pos) -> std::list< itkImageSpatialObject2F_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkImageSpatialObject2F_Pointer >::iterator

        erase(self, first, last) -> std::list< itkImageSpatialObject2F_Pointer >::iterator

        Parameters
        ----------
        first: std::list< itkImageSpatialObject2F_Pointer >::iterator
        last: std::list< itkImageSpatialObject2F_Pointer >::iterator

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer_erase(self, *args)

    def __init__(self, *args):
        r"""
        __init__(self) -> listitkImageSpatialObject2F_Pointer
        __init__(self, other) -> listitkImageSpatialObject2F_Pointer

        Parameters
        ----------
        other: std::list< itkImageSpatialObject2F_Pointer > const &

        __init__(self, size) -> listitkImageSpatialObject2F_Pointer

        Parameters
        ----------
        size: std::list< itkImageSpatialObject2F_Pointer >::size_type

        __init__(self, size, value) -> listitkImageSpatialObject2F_Pointer

        Parameters
        ----------
        size: std::list< itkImageSpatialObject2F_Pointer >::size_type
        value: std::list< itkImageSpatialObject2F_Pointer >::value_type const &

        """
        _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer_swiginit(self, _itkImageSpatialObjectPython.new_listitkImageSpatialObject2F_Pointer(*args))

    def push_back(self, x):
        r"""
        push_back(self, x)

        Parameters
        ----------
        x: std::list< itkImageSpatialObject2F_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer_push_back(self, x)

    def front(self):
        r"""front(self) -> std::list< itkImageSpatialObject2F_Pointer >::value_type const &"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer_front(self)

    def back(self):
        r"""back(self) -> std::list< itkImageSpatialObject2F_Pointer >::value_type const &"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer_back(self)

    def assign(self, n, x):
        r"""
        assign(self, n, x)

        Parameters
        ----------
        n: std::list< itkImageSpatialObject2F_Pointer >::size_type
        x: std::list< itkImageSpatialObject2F_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer_assign(self, n, x)

    def resize(self, *args):
        r"""
        resize(self, new_size)

        Parameters
        ----------
        new_size: std::list< itkImageSpatialObject2F_Pointer >::size_type

        resize(self, new_size, x)

        Parameters
        ----------
        new_size: std::list< itkImageSpatialObject2F_Pointer >::size_type
        x: std::list< itkImageSpatialObject2F_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer_resize(self, *args)

    def insert(self, *args):
        r"""
        insert(self, pos, x) -> std::list< itkImageSpatialObject2F_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkImageSpatialObject2F_Pointer >::iterator
        x: std::list< itkImageSpatialObject2F_Pointer >::value_type const &

        insert(self, pos, n, x)

        Parameters
        ----------
        pos: std::list< itkImageSpatialObject2F_Pointer >::iterator
        n: std::list< itkImageSpatialObject2F_Pointer >::size_type
        x: std::list< itkImageSpatialObject2F_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer_insert(self, *args)

    def pop_front(self):
        r"""pop_front(self)"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer_pop_front(self)

    def push_front(self, x):
        r"""
        push_front(self, x)

        Parameters
        ----------
        x: std::list< itkImageSpatialObject2F_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer_push_front(self, x)

    def reverse(self):
        r"""reverse(self)"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer_reverse(self)
    __swig_destroy__ = _itkImageSpatialObjectPython.delete_listitkImageSpatialObject2F_Pointer

# Register listitkImageSpatialObject2F_Pointer in _itkImageSpatialObjectPython:
_itkImageSpatialObjectPython.listitkImageSpatialObject2F_Pointer_swigregister(listitkImageSpatialObject2F_Pointer)
class listitkImageSpatialObject3UC_Pointer(collections.abc.MutableSequence if _swig_python_version_info >= (3, 3) else collections.MutableSequence):
    r"""Proxy of C++ std::list< itkImageSpatialObject3UC_Pointer > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        r"""iterator(self) -> SwigPyIterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        r"""__nonzero__(self) -> bool"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer___nonzero__(self)

    def __bool__(self):
        r"""__bool__(self) -> bool"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer___bool__(self)

    def __len__(self):
        r"""__len__(self) -> std::list< itkImageSpatialObject3UC_Pointer >::size_type"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer___len__(self)

    def __getslice__(self, i, j):
        r"""
        __getslice__(self, i, j) -> listitkImageSpatialObject3UC_Pointer

        Parameters
        ----------
        i: std::list< itkImageSpatialObject3UC_Pointer >::difference_type
        j: std::list< itkImageSpatialObject3UC_Pointer >::difference_type

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer___getslice__(self, i, j)

    def __setslice__(self, *args):
        r"""
        __setslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject3UC_Pointer >::difference_type
        j: std::list< itkImageSpatialObject3UC_Pointer >::difference_type

        __setslice__(self, i, j, v)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject3UC_Pointer >::difference_type
        j: std::list< itkImageSpatialObject3UC_Pointer >::difference_type
        v: std::list< itkImageSpatialObject3UC_Pointer,std::allocator< itkImageSpatialObject3UC_Pointer > > const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer___setslice__(self, *args)

    def __delslice__(self, i, j):
        r"""
        __delslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject3UC_Pointer >::difference_type
        j: std::list< itkImageSpatialObject3UC_Pointer >::difference_type

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer___delslice__(self, i, j)

    def __delitem__(self, *args):
        r"""
        __delitem__(self, i)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject3UC_Pointer >::difference_type

        __delitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer___delitem__(self, *args)

    def __getitem__(self, *args):
        r"""
        __getitem__(self, slice) -> listitkImageSpatialObject3UC_Pointer

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __getitem__(self, i) -> std::list< itkImageSpatialObject3UC_Pointer >::value_type const &

        Parameters
        ----------
        i: std::list< itkImageSpatialObject3UC_Pointer >::difference_type

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer___getitem__(self, *args)

    def __setitem__(self, *args):
        r"""
        __setitem__(self, slice, v)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *
        v: std::list< itkImageSpatialObject3UC_Pointer,std::allocator< itkImageSpatialObject3UC_Pointer > > const &

        __setitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __setitem__(self, i, x)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject3UC_Pointer >::difference_type
        x: std::list< itkImageSpatialObject3UC_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer___setitem__(self, *args)

    def pop(self):
        r"""pop(self) -> std::list< itkImageSpatialObject3UC_Pointer >::value_type"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer_pop(self)

    def append(self, x):
        r"""
        append(self, x)

        Parameters
        ----------
        x: std::list< itkImageSpatialObject3UC_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer_append(self, x)

    def empty(self):
        r"""empty(self) -> bool"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer_empty(self)

    def size(self):
        r"""size(self) -> std::list< itkImageSpatialObject3UC_Pointer >::size_type"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer_size(self)

    def swap(self, v):
        r"""
        swap(self, v)

        Parameters
        ----------
        v: std::list< itkImageSpatialObject3UC_Pointer > &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer_swap(self, v)

    def begin(self):
        r"""begin(self) -> std::list< itkImageSpatialObject3UC_Pointer >::iterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer_begin(self)

    def end(self):
        r"""end(self) -> std::list< itkImageSpatialObject3UC_Pointer >::iterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer_end(self)

    def rbegin(self):
        r"""rbegin(self) -> std::list< itkImageSpatialObject3UC_Pointer >::reverse_iterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer_rbegin(self)

    def rend(self):
        r"""rend(self) -> std::list< itkImageSpatialObject3UC_Pointer >::reverse_iterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer_rend(self)

    def clear(self):
        r"""clear(self)"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer_clear(self)

    def get_allocator(self):
        r"""get_allocator(self) -> std::list< itkImageSpatialObject3UC_Pointer >::allocator_type"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer_get_allocator(self)

    def pop_back(self):
        r"""pop_back(self)"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer_pop_back(self)

    def erase(self, *args):
        r"""
        erase(self, pos) -> std::list< itkImageSpatialObject3UC_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkImageSpatialObject3UC_Pointer >::iterator

        erase(self, first, last) -> std::list< itkImageSpatialObject3UC_Pointer >::iterator

        Parameters
        ----------
        first: std::list< itkImageSpatialObject3UC_Pointer >::iterator
        last: std::list< itkImageSpatialObject3UC_Pointer >::iterator

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer_erase(self, *args)

    def __init__(self, *args):
        r"""
        __init__(self) -> listitkImageSpatialObject3UC_Pointer
        __init__(self, other) -> listitkImageSpatialObject3UC_Pointer

        Parameters
        ----------
        other: std::list< itkImageSpatialObject3UC_Pointer > const &

        __init__(self, size) -> listitkImageSpatialObject3UC_Pointer

        Parameters
        ----------
        size: std::list< itkImageSpatialObject3UC_Pointer >::size_type

        __init__(self, size, value) -> listitkImageSpatialObject3UC_Pointer

        Parameters
        ----------
        size: std::list< itkImageSpatialObject3UC_Pointer >::size_type
        value: std::list< itkImageSpatialObject3UC_Pointer >::value_type const &

        """
        _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer_swiginit(self, _itkImageSpatialObjectPython.new_listitkImageSpatialObject3UC_Pointer(*args))

    def push_back(self, x):
        r"""
        push_back(self, x)

        Parameters
        ----------
        x: std::list< itkImageSpatialObject3UC_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer_push_back(self, x)

    def front(self):
        r"""front(self) -> std::list< itkImageSpatialObject3UC_Pointer >::value_type const &"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer_front(self)

    def back(self):
        r"""back(self) -> std::list< itkImageSpatialObject3UC_Pointer >::value_type const &"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer_back(self)

    def assign(self, n, x):
        r"""
        assign(self, n, x)

        Parameters
        ----------
        n: std::list< itkImageSpatialObject3UC_Pointer >::size_type
        x: std::list< itkImageSpatialObject3UC_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer_assign(self, n, x)

    def resize(self, *args):
        r"""
        resize(self, new_size)

        Parameters
        ----------
        new_size: std::list< itkImageSpatialObject3UC_Pointer >::size_type

        resize(self, new_size, x)

        Parameters
        ----------
        new_size: std::list< itkImageSpatialObject3UC_Pointer >::size_type
        x: std::list< itkImageSpatialObject3UC_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer_resize(self, *args)

    def insert(self, *args):
        r"""
        insert(self, pos, x) -> std::list< itkImageSpatialObject3UC_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkImageSpatialObject3UC_Pointer >::iterator
        x: std::list< itkImageSpatialObject3UC_Pointer >::value_type const &

        insert(self, pos, n, x)

        Parameters
        ----------
        pos: std::list< itkImageSpatialObject3UC_Pointer >::iterator
        n: std::list< itkImageSpatialObject3UC_Pointer >::size_type
        x: std::list< itkImageSpatialObject3UC_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer_insert(self, *args)

    def pop_front(self):
        r"""pop_front(self)"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer_pop_front(self)

    def push_front(self, x):
        r"""
        push_front(self, x)

        Parameters
        ----------
        x: std::list< itkImageSpatialObject3UC_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer_push_front(self, x)

    def reverse(self):
        r"""reverse(self)"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer_reverse(self)
    __swig_destroy__ = _itkImageSpatialObjectPython.delete_listitkImageSpatialObject3UC_Pointer

# Register listitkImageSpatialObject3UC_Pointer in _itkImageSpatialObjectPython:
_itkImageSpatialObjectPython.listitkImageSpatialObject3UC_Pointer_swigregister(listitkImageSpatialObject3UC_Pointer)
class listitkImageSpatialObject3SS_Pointer(collections.abc.MutableSequence if _swig_python_version_info >= (3, 3) else collections.MutableSequence):
    r"""Proxy of C++ std::list< itkImageSpatialObject3SS_Pointer > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        r"""iterator(self) -> SwigPyIterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        r"""__nonzero__(self) -> bool"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer___nonzero__(self)

    def __bool__(self):
        r"""__bool__(self) -> bool"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer___bool__(self)

    def __len__(self):
        r"""__len__(self) -> std::list< itkImageSpatialObject3SS_Pointer >::size_type"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer___len__(self)

    def __getslice__(self, i, j):
        r"""
        __getslice__(self, i, j) -> listitkImageSpatialObject3SS_Pointer

        Parameters
        ----------
        i: std::list< itkImageSpatialObject3SS_Pointer >::difference_type
        j: std::list< itkImageSpatialObject3SS_Pointer >::difference_type

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer___getslice__(self, i, j)

    def __setslice__(self, *args):
        r"""
        __setslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject3SS_Pointer >::difference_type
        j: std::list< itkImageSpatialObject3SS_Pointer >::difference_type

        __setslice__(self, i, j, v)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject3SS_Pointer >::difference_type
        j: std::list< itkImageSpatialObject3SS_Pointer >::difference_type
        v: std::list< itkImageSpatialObject3SS_Pointer,std::allocator< itkImageSpatialObject3SS_Pointer > > const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer___setslice__(self, *args)

    def __delslice__(self, i, j):
        r"""
        __delslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject3SS_Pointer >::difference_type
        j: std::list< itkImageSpatialObject3SS_Pointer >::difference_type

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer___delslice__(self, i, j)

    def __delitem__(self, *args):
        r"""
        __delitem__(self, i)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject3SS_Pointer >::difference_type

        __delitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer___delitem__(self, *args)

    def __getitem__(self, *args):
        r"""
        __getitem__(self, slice) -> listitkImageSpatialObject3SS_Pointer

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __getitem__(self, i) -> std::list< itkImageSpatialObject3SS_Pointer >::value_type const &

        Parameters
        ----------
        i: std::list< itkImageSpatialObject3SS_Pointer >::difference_type

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer___getitem__(self, *args)

    def __setitem__(self, *args):
        r"""
        __setitem__(self, slice, v)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *
        v: std::list< itkImageSpatialObject3SS_Pointer,std::allocator< itkImageSpatialObject3SS_Pointer > > const &

        __setitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __setitem__(self, i, x)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject3SS_Pointer >::difference_type
        x: std::list< itkImageSpatialObject3SS_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer___setitem__(self, *args)

    def pop(self):
        r"""pop(self) -> std::list< itkImageSpatialObject3SS_Pointer >::value_type"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer_pop(self)

    def append(self, x):
        r"""
        append(self, x)

        Parameters
        ----------
        x: std::list< itkImageSpatialObject3SS_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer_append(self, x)

    def empty(self):
        r"""empty(self) -> bool"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer_empty(self)

    def size(self):
        r"""size(self) -> std::list< itkImageSpatialObject3SS_Pointer >::size_type"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer_size(self)

    def swap(self, v):
        r"""
        swap(self, v)

        Parameters
        ----------
        v: std::list< itkImageSpatialObject3SS_Pointer > &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer_swap(self, v)

    def begin(self):
        r"""begin(self) -> std::list< itkImageSpatialObject3SS_Pointer >::iterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer_begin(self)

    def end(self):
        r"""end(self) -> std::list< itkImageSpatialObject3SS_Pointer >::iterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer_end(self)

    def rbegin(self):
        r"""rbegin(self) -> std::list< itkImageSpatialObject3SS_Pointer >::reverse_iterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer_rbegin(self)

    def rend(self):
        r"""rend(self) -> std::list< itkImageSpatialObject3SS_Pointer >::reverse_iterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer_rend(self)

    def clear(self):
        r"""clear(self)"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer_clear(self)

    def get_allocator(self):
        r"""get_allocator(self) -> std::list< itkImageSpatialObject3SS_Pointer >::allocator_type"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer_get_allocator(self)

    def pop_back(self):
        r"""pop_back(self)"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer_pop_back(self)

    def erase(self, *args):
        r"""
        erase(self, pos) -> std::list< itkImageSpatialObject3SS_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkImageSpatialObject3SS_Pointer >::iterator

        erase(self, first, last) -> std::list< itkImageSpatialObject3SS_Pointer >::iterator

        Parameters
        ----------
        first: std::list< itkImageSpatialObject3SS_Pointer >::iterator
        last: std::list< itkImageSpatialObject3SS_Pointer >::iterator

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer_erase(self, *args)

    def __init__(self, *args):
        r"""
        __init__(self) -> listitkImageSpatialObject3SS_Pointer
        __init__(self, other) -> listitkImageSpatialObject3SS_Pointer

        Parameters
        ----------
        other: std::list< itkImageSpatialObject3SS_Pointer > const &

        __init__(self, size) -> listitkImageSpatialObject3SS_Pointer

        Parameters
        ----------
        size: std::list< itkImageSpatialObject3SS_Pointer >::size_type

        __init__(self, size, value) -> listitkImageSpatialObject3SS_Pointer

        Parameters
        ----------
        size: std::list< itkImageSpatialObject3SS_Pointer >::size_type
        value: std::list< itkImageSpatialObject3SS_Pointer >::value_type const &

        """
        _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer_swiginit(self, _itkImageSpatialObjectPython.new_listitkImageSpatialObject3SS_Pointer(*args))

    def push_back(self, x):
        r"""
        push_back(self, x)

        Parameters
        ----------
        x: std::list< itkImageSpatialObject3SS_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer_push_back(self, x)

    def front(self):
        r"""front(self) -> std::list< itkImageSpatialObject3SS_Pointer >::value_type const &"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer_front(self)

    def back(self):
        r"""back(self) -> std::list< itkImageSpatialObject3SS_Pointer >::value_type const &"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer_back(self)

    def assign(self, n, x):
        r"""
        assign(self, n, x)

        Parameters
        ----------
        n: std::list< itkImageSpatialObject3SS_Pointer >::size_type
        x: std::list< itkImageSpatialObject3SS_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer_assign(self, n, x)

    def resize(self, *args):
        r"""
        resize(self, new_size)

        Parameters
        ----------
        new_size: std::list< itkImageSpatialObject3SS_Pointer >::size_type

        resize(self, new_size, x)

        Parameters
        ----------
        new_size: std::list< itkImageSpatialObject3SS_Pointer >::size_type
        x: std::list< itkImageSpatialObject3SS_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer_resize(self, *args)

    def insert(self, *args):
        r"""
        insert(self, pos, x) -> std::list< itkImageSpatialObject3SS_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkImageSpatialObject3SS_Pointer >::iterator
        x: std::list< itkImageSpatialObject3SS_Pointer >::value_type const &

        insert(self, pos, n, x)

        Parameters
        ----------
        pos: std::list< itkImageSpatialObject3SS_Pointer >::iterator
        n: std::list< itkImageSpatialObject3SS_Pointer >::size_type
        x: std::list< itkImageSpatialObject3SS_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer_insert(self, *args)

    def pop_front(self):
        r"""pop_front(self)"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer_pop_front(self)

    def push_front(self, x):
        r"""
        push_front(self, x)

        Parameters
        ----------
        x: std::list< itkImageSpatialObject3SS_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer_push_front(self, x)

    def reverse(self):
        r"""reverse(self)"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer_reverse(self)
    __swig_destroy__ = _itkImageSpatialObjectPython.delete_listitkImageSpatialObject3SS_Pointer

# Register listitkImageSpatialObject3SS_Pointer in _itkImageSpatialObjectPython:
_itkImageSpatialObjectPython.listitkImageSpatialObject3SS_Pointer_swigregister(listitkImageSpatialObject3SS_Pointer)
class listitkImageSpatialObject3F_Pointer(collections.abc.MutableSequence if _swig_python_version_info >= (3, 3) else collections.MutableSequence):
    r"""Proxy of C++ std::list< itkImageSpatialObject3F_Pointer > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        r"""iterator(self) -> SwigPyIterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        r"""__nonzero__(self) -> bool"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer___nonzero__(self)

    def __bool__(self):
        r"""__bool__(self) -> bool"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer___bool__(self)

    def __len__(self):
        r"""__len__(self) -> std::list< itkImageSpatialObject3F_Pointer >::size_type"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer___len__(self)

    def __getslice__(self, i, j):
        r"""
        __getslice__(self, i, j) -> listitkImageSpatialObject3F_Pointer

        Parameters
        ----------
        i: std::list< itkImageSpatialObject3F_Pointer >::difference_type
        j: std::list< itkImageSpatialObject3F_Pointer >::difference_type

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer___getslice__(self, i, j)

    def __setslice__(self, *args):
        r"""
        __setslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject3F_Pointer >::difference_type
        j: std::list< itkImageSpatialObject3F_Pointer >::difference_type

        __setslice__(self, i, j, v)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject3F_Pointer >::difference_type
        j: std::list< itkImageSpatialObject3F_Pointer >::difference_type
        v: std::list< itkImageSpatialObject3F_Pointer,std::allocator< itkImageSpatialObject3F_Pointer > > const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer___setslice__(self, *args)

    def __delslice__(self, i, j):
        r"""
        __delslice__(self, i, j)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject3F_Pointer >::difference_type
        j: std::list< itkImageSpatialObject3F_Pointer >::difference_type

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer___delslice__(self, i, j)

    def __delitem__(self, *args):
        r"""
        __delitem__(self, i)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject3F_Pointer >::difference_type

        __delitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer___delitem__(self, *args)

    def __getitem__(self, *args):
        r"""
        __getitem__(self, slice) -> listitkImageSpatialObject3F_Pointer

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __getitem__(self, i) -> std::list< itkImageSpatialObject3F_Pointer >::value_type const &

        Parameters
        ----------
        i: std::list< itkImageSpatialObject3F_Pointer >::difference_type

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer___getitem__(self, *args)

    def __setitem__(self, *args):
        r"""
        __setitem__(self, slice, v)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *
        v: std::list< itkImageSpatialObject3F_Pointer,std::allocator< itkImageSpatialObject3F_Pointer > > const &

        __setitem__(self, slice)

        Parameters
        ----------
        slice: SWIGPY_SLICEOBJECT *

        __setitem__(self, i, x)

        Parameters
        ----------
        i: std::list< itkImageSpatialObject3F_Pointer >::difference_type
        x: std::list< itkImageSpatialObject3F_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer___setitem__(self, *args)

    def pop(self):
        r"""pop(self) -> std::list< itkImageSpatialObject3F_Pointer >::value_type"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer_pop(self)

    def append(self, x):
        r"""
        append(self, x)

        Parameters
        ----------
        x: std::list< itkImageSpatialObject3F_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer_append(self, x)

    def empty(self):
        r"""empty(self) -> bool"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer_empty(self)

    def size(self):
        r"""size(self) -> std::list< itkImageSpatialObject3F_Pointer >::size_type"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer_size(self)

    def swap(self, v):
        r"""
        swap(self, v)

        Parameters
        ----------
        v: std::list< itkImageSpatialObject3F_Pointer > &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer_swap(self, v)

    def begin(self):
        r"""begin(self) -> std::list< itkImageSpatialObject3F_Pointer >::iterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer_begin(self)

    def end(self):
        r"""end(self) -> std::list< itkImageSpatialObject3F_Pointer >::iterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer_end(self)

    def rbegin(self):
        r"""rbegin(self) -> std::list< itkImageSpatialObject3F_Pointer >::reverse_iterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer_rbegin(self)

    def rend(self):
        r"""rend(self) -> std::list< itkImageSpatialObject3F_Pointer >::reverse_iterator"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer_rend(self)

    def clear(self):
        r"""clear(self)"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer_clear(self)

    def get_allocator(self):
        r"""get_allocator(self) -> std::list< itkImageSpatialObject3F_Pointer >::allocator_type"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer_get_allocator(self)

    def pop_back(self):
        r"""pop_back(self)"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer_pop_back(self)

    def erase(self, *args):
        r"""
        erase(self, pos) -> std::list< itkImageSpatialObject3F_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkImageSpatialObject3F_Pointer >::iterator

        erase(self, first, last) -> std::list< itkImageSpatialObject3F_Pointer >::iterator

        Parameters
        ----------
        first: std::list< itkImageSpatialObject3F_Pointer >::iterator
        last: std::list< itkImageSpatialObject3F_Pointer >::iterator

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer_erase(self, *args)

    def __init__(self, *args):
        r"""
        __init__(self) -> listitkImageSpatialObject3F_Pointer
        __init__(self, other) -> listitkImageSpatialObject3F_Pointer

        Parameters
        ----------
        other: std::list< itkImageSpatialObject3F_Pointer > const &

        __init__(self, size) -> listitkImageSpatialObject3F_Pointer

        Parameters
        ----------
        size: std::list< itkImageSpatialObject3F_Pointer >::size_type

        __init__(self, size, value) -> listitkImageSpatialObject3F_Pointer

        Parameters
        ----------
        size: std::list< itkImageSpatialObject3F_Pointer >::size_type
        value: std::list< itkImageSpatialObject3F_Pointer >::value_type const &

        """
        _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer_swiginit(self, _itkImageSpatialObjectPython.new_listitkImageSpatialObject3F_Pointer(*args))

    def push_back(self, x):
        r"""
        push_back(self, x)

        Parameters
        ----------
        x: std::list< itkImageSpatialObject3F_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer_push_back(self, x)

    def front(self):
        r"""front(self) -> std::list< itkImageSpatialObject3F_Pointer >::value_type const &"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer_front(self)

    def back(self):
        r"""back(self) -> std::list< itkImageSpatialObject3F_Pointer >::value_type const &"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer_back(self)

    def assign(self, n, x):
        r"""
        assign(self, n, x)

        Parameters
        ----------
        n: std::list< itkImageSpatialObject3F_Pointer >::size_type
        x: std::list< itkImageSpatialObject3F_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer_assign(self, n, x)

    def resize(self, *args):
        r"""
        resize(self, new_size)

        Parameters
        ----------
        new_size: std::list< itkImageSpatialObject3F_Pointer >::size_type

        resize(self, new_size, x)

        Parameters
        ----------
        new_size: std::list< itkImageSpatialObject3F_Pointer >::size_type
        x: std::list< itkImageSpatialObject3F_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer_resize(self, *args)

    def insert(self, *args):
        r"""
        insert(self, pos, x) -> std::list< itkImageSpatialObject3F_Pointer >::iterator

        Parameters
        ----------
        pos: std::list< itkImageSpatialObject3F_Pointer >::iterator
        x: std::list< itkImageSpatialObject3F_Pointer >::value_type const &

        insert(self, pos, n, x)

        Parameters
        ----------
        pos: std::list< itkImageSpatialObject3F_Pointer >::iterator
        n: std::list< itkImageSpatialObject3F_Pointer >::size_type
        x: std::list< itkImageSpatialObject3F_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer_insert(self, *args)

    def pop_front(self):
        r"""pop_front(self)"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer_pop_front(self)

    def push_front(self, x):
        r"""
        push_front(self, x)

        Parameters
        ----------
        x: std::list< itkImageSpatialObject3F_Pointer >::value_type const &

        """
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer_push_front(self, x)

    def reverse(self):
        r"""reverse(self)"""
        return _itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer_reverse(self)
    __swig_destroy__ = _itkImageSpatialObjectPython.delete_listitkImageSpatialObject3F_Pointer

# Register listitkImageSpatialObject3F_Pointer in _itkImageSpatialObjectPython:
_itkImageSpatialObjectPython.listitkImageSpatialObject3F_Pointer_swigregister(listitkImageSpatialObject3F_Pointer)

def itkImageSpatialObject2F_New():
    return itkImageSpatialObject2F.New()

class itkImageSpatialObject2F(itk.itkSpatialObjectBasePython.itkSpatialObject2):
    r"""Proxy of C++ itkImageSpatialObject2F class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkImageSpatialObject2F_Pointer"""
        return _itkImageSpatialObjectPython.itkImageSpatialObject2F___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkImageSpatialObject2F_Pointer"""
        return _itkImageSpatialObjectPython.itkImageSpatialObject2F_Clone(self)

    def SetImage(self, image):
        r"""
        SetImage(self, image)

        Parameters
        ----------
        image: itkImageF2 const *

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject2F_SetImage(self, image)

    def GetImage(self):
        r"""GetImage(self) -> itkImageF2"""
        return _itkImageSpatialObjectPython.itkImageSpatialObject2F_GetImage(self)

    def ValueAtInObjectSpace(self, *args):
        r"""
        ValueAtInObjectSpace(self, point, value, depth=0, name="") -> bool

        Parameters
        ----------
        point: itkPointD2 const &
        value: double &
        depth: unsigned int
        name: std::string const &

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject2F_ValueAtInObjectSpace(self, *args)

    def SetSliceNumber(self, *args):
        r"""
        SetSliceNumber(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        SetSliceNumber(self, dimension, position)

        Parameters
        ----------
        dimension: unsigned int
        position: int

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject2F_SetSliceNumber(self, *args)

    def GetSliceNumber(self, *args):
        r"""
        GetSliceNumber(self) -> itkIndex2
        GetSliceNumber(self, dimension) -> int

        Parameters
        ----------
        dimension: unsigned int

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject2F_GetSliceNumber(self, *args)

    def SetInterpolator(self, interpolator):
        r"""
        SetInterpolator(self, interpolator)

        Parameters
        ----------
        interpolator: itkInterpolateImageFunctionIF2D *

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject2F_SetInterpolator(self, interpolator)

    def GetInterpolator(self):
        r"""GetInterpolator(self) -> itkInterpolateImageFunctionIF2D"""
        return _itkImageSpatialObjectPython.itkImageSpatialObject2F_GetInterpolator(self)
    __swig_destroy__ = _itkImageSpatialObjectPython.delete_itkImageSpatialObject2F

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSpatialObject2F

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject2F_cast(obj)

    def New(*args, **kargs):
        """New() -> itkImageSpatialObject2F

        Create a new object of the class itkImageSpatialObject2F and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkImageSpatialObject2F.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkImageSpatialObject2F.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkImageSpatialObject2F.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkImageSpatialObject2F in _itkImageSpatialObjectPython:
_itkImageSpatialObjectPython.itkImageSpatialObject2F_swigregister(itkImageSpatialObject2F)

def itkImageSpatialObject2SS_New():
    return itkImageSpatialObject2SS.New()

class itkImageSpatialObject2SS(itk.itkSpatialObjectBasePython.itkSpatialObject2):
    r"""Proxy of C++ itkImageSpatialObject2SS class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkImageSpatialObject2SS_Pointer"""
        return _itkImageSpatialObjectPython.itkImageSpatialObject2SS___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkImageSpatialObject2SS_Pointer"""
        return _itkImageSpatialObjectPython.itkImageSpatialObject2SS_Clone(self)

    def SetImage(self, image):
        r"""
        SetImage(self, image)

        Parameters
        ----------
        image: itkImageSS2 const *

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject2SS_SetImage(self, image)

    def GetImage(self):
        r"""GetImage(self) -> itkImageSS2"""
        return _itkImageSpatialObjectPython.itkImageSpatialObject2SS_GetImage(self)

    def ValueAtInObjectSpace(self, *args):
        r"""
        ValueAtInObjectSpace(self, point, value, depth=0, name="") -> bool

        Parameters
        ----------
        point: itkPointD2 const &
        value: double &
        depth: unsigned int
        name: std::string const &

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject2SS_ValueAtInObjectSpace(self, *args)

    def SetSliceNumber(self, *args):
        r"""
        SetSliceNumber(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        SetSliceNumber(self, dimension, position)

        Parameters
        ----------
        dimension: unsigned int
        position: int

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject2SS_SetSliceNumber(self, *args)

    def GetSliceNumber(self, *args):
        r"""
        GetSliceNumber(self) -> itkIndex2
        GetSliceNumber(self, dimension) -> int

        Parameters
        ----------
        dimension: unsigned int

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject2SS_GetSliceNumber(self, *args)

    def SetInterpolator(self, interpolator):
        r"""
        SetInterpolator(self, interpolator)

        Parameters
        ----------
        interpolator: itkInterpolateImageFunctionISS2D *

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject2SS_SetInterpolator(self, interpolator)

    def GetInterpolator(self):
        r"""GetInterpolator(self) -> itkInterpolateImageFunctionISS2D"""
        return _itkImageSpatialObjectPython.itkImageSpatialObject2SS_GetInterpolator(self)
    __swig_destroy__ = _itkImageSpatialObjectPython.delete_itkImageSpatialObject2SS

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSpatialObject2SS

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject2SS_cast(obj)

    def New(*args, **kargs):
        """New() -> itkImageSpatialObject2SS

        Create a new object of the class itkImageSpatialObject2SS and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkImageSpatialObject2SS.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkImageSpatialObject2SS.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkImageSpatialObject2SS.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkImageSpatialObject2SS in _itkImageSpatialObjectPython:
_itkImageSpatialObjectPython.itkImageSpatialObject2SS_swigregister(itkImageSpatialObject2SS)

def itkImageSpatialObject2UC_New():
    return itkImageSpatialObject2UC.New()

class itkImageSpatialObject2UC(itk.itkSpatialObjectBasePython.itkSpatialObject2):
    r"""Proxy of C++ itkImageSpatialObject2UC class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkImageSpatialObject2UC_Pointer"""
        return _itkImageSpatialObjectPython.itkImageSpatialObject2UC___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkImageSpatialObject2UC_Pointer"""
        return _itkImageSpatialObjectPython.itkImageSpatialObject2UC_Clone(self)

    def SetImage(self, image):
        r"""
        SetImage(self, image)

        Parameters
        ----------
        image: itkImageUC2 const *

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject2UC_SetImage(self, image)

    def GetImage(self):
        r"""GetImage(self) -> itkImageUC2"""
        return _itkImageSpatialObjectPython.itkImageSpatialObject2UC_GetImage(self)

    def ValueAtInObjectSpace(self, *args):
        r"""
        ValueAtInObjectSpace(self, point, value, depth=0, name="") -> bool

        Parameters
        ----------
        point: itkPointD2 const &
        value: double &
        depth: unsigned int
        name: std::string const &

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject2UC_ValueAtInObjectSpace(self, *args)

    def SetSliceNumber(self, *args):
        r"""
        SetSliceNumber(self, _arg)

        Parameters
        ----------
        _arg: itkIndex2

        SetSliceNumber(self, dimension, position)

        Parameters
        ----------
        dimension: unsigned int
        position: int

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject2UC_SetSliceNumber(self, *args)

    def GetSliceNumber(self, *args):
        r"""
        GetSliceNumber(self) -> itkIndex2
        GetSliceNumber(self, dimension) -> int

        Parameters
        ----------
        dimension: unsigned int

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject2UC_GetSliceNumber(self, *args)

    def SetInterpolator(self, interpolator):
        r"""
        SetInterpolator(self, interpolator)

        Parameters
        ----------
        interpolator: itkInterpolateImageFunctionIUC2D *

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject2UC_SetInterpolator(self, interpolator)

    def GetInterpolator(self):
        r"""GetInterpolator(self) -> itkInterpolateImageFunctionIUC2D"""
        return _itkImageSpatialObjectPython.itkImageSpatialObject2UC_GetInterpolator(self)
    __swig_destroy__ = _itkImageSpatialObjectPython.delete_itkImageSpatialObject2UC

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSpatialObject2UC

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject2UC_cast(obj)

    def New(*args, **kargs):
        """New() -> itkImageSpatialObject2UC

        Create a new object of the class itkImageSpatialObject2UC and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkImageSpatialObject2UC.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkImageSpatialObject2UC.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkImageSpatialObject2UC.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkImageSpatialObject2UC in _itkImageSpatialObjectPython:
_itkImageSpatialObjectPython.itkImageSpatialObject2UC_swigregister(itkImageSpatialObject2UC)

def itkImageSpatialObject3F_New():
    return itkImageSpatialObject3F.New()

class itkImageSpatialObject3F(itk.itkSpatialObjectBasePython.itkSpatialObject3):
    r"""Proxy of C++ itkImageSpatialObject3F class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkImageSpatialObject3F_Pointer"""
        return _itkImageSpatialObjectPython.itkImageSpatialObject3F___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkImageSpatialObject3F_Pointer"""
        return _itkImageSpatialObjectPython.itkImageSpatialObject3F_Clone(self)

    def SetImage(self, image):
        r"""
        SetImage(self, image)

        Parameters
        ----------
        image: itkImageF3 const *

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject3F_SetImage(self, image)

    def GetImage(self):
        r"""GetImage(self) -> itkImageF3"""
        return _itkImageSpatialObjectPython.itkImageSpatialObject3F_GetImage(self)

    def ValueAtInObjectSpace(self, *args):
        r"""
        ValueAtInObjectSpace(self, point, value, depth=0, name="") -> bool

        Parameters
        ----------
        point: itkPointD3 const &
        value: double &
        depth: unsigned int
        name: std::string const &

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject3F_ValueAtInObjectSpace(self, *args)

    def SetSliceNumber(self, *args):
        r"""
        SetSliceNumber(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        SetSliceNumber(self, dimension, position)

        Parameters
        ----------
        dimension: unsigned int
        position: int

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject3F_SetSliceNumber(self, *args)

    def GetSliceNumber(self, *args):
        r"""
        GetSliceNumber(self) -> itkIndex3
        GetSliceNumber(self, dimension) -> int

        Parameters
        ----------
        dimension: unsigned int

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject3F_GetSliceNumber(self, *args)

    def SetInterpolator(self, interpolator):
        r"""
        SetInterpolator(self, interpolator)

        Parameters
        ----------
        interpolator: itkInterpolateImageFunctionIF3D *

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject3F_SetInterpolator(self, interpolator)

    def GetInterpolator(self):
        r"""GetInterpolator(self) -> itkInterpolateImageFunctionIF3D"""
        return _itkImageSpatialObjectPython.itkImageSpatialObject3F_GetInterpolator(self)
    __swig_destroy__ = _itkImageSpatialObjectPython.delete_itkImageSpatialObject3F

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSpatialObject3F

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject3F_cast(obj)

    def New(*args, **kargs):
        """New() -> itkImageSpatialObject3F

        Create a new object of the class itkImageSpatialObject3F and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkImageSpatialObject3F.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkImageSpatialObject3F.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkImageSpatialObject3F.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkImageSpatialObject3F in _itkImageSpatialObjectPython:
_itkImageSpatialObjectPython.itkImageSpatialObject3F_swigregister(itkImageSpatialObject3F)

def itkImageSpatialObject3SS_New():
    return itkImageSpatialObject3SS.New()

class itkImageSpatialObject3SS(itk.itkSpatialObjectBasePython.itkSpatialObject3):
    r"""Proxy of C++ itkImageSpatialObject3SS class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkImageSpatialObject3SS_Pointer"""
        return _itkImageSpatialObjectPython.itkImageSpatialObject3SS___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkImageSpatialObject3SS_Pointer"""
        return _itkImageSpatialObjectPython.itkImageSpatialObject3SS_Clone(self)

    def SetImage(self, image):
        r"""
        SetImage(self, image)

        Parameters
        ----------
        image: itkImageSS3 const *

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject3SS_SetImage(self, image)

    def GetImage(self):
        r"""GetImage(self) -> itkImageSS3"""
        return _itkImageSpatialObjectPython.itkImageSpatialObject3SS_GetImage(self)

    def ValueAtInObjectSpace(self, *args):
        r"""
        ValueAtInObjectSpace(self, point, value, depth=0, name="") -> bool

        Parameters
        ----------
        point: itkPointD3 const &
        value: double &
        depth: unsigned int
        name: std::string const &

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject3SS_ValueAtInObjectSpace(self, *args)

    def SetSliceNumber(self, *args):
        r"""
        SetSliceNumber(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        SetSliceNumber(self, dimension, position)

        Parameters
        ----------
        dimension: unsigned int
        position: int

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject3SS_SetSliceNumber(self, *args)

    def GetSliceNumber(self, *args):
        r"""
        GetSliceNumber(self) -> itkIndex3
        GetSliceNumber(self, dimension) -> int

        Parameters
        ----------
        dimension: unsigned int

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject3SS_GetSliceNumber(self, *args)

    def SetInterpolator(self, interpolator):
        r"""
        SetInterpolator(self, interpolator)

        Parameters
        ----------
        interpolator: itkInterpolateImageFunctionISS3D *

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject3SS_SetInterpolator(self, interpolator)

    def GetInterpolator(self):
        r"""GetInterpolator(self) -> itkInterpolateImageFunctionISS3D"""
        return _itkImageSpatialObjectPython.itkImageSpatialObject3SS_GetInterpolator(self)
    __swig_destroy__ = _itkImageSpatialObjectPython.delete_itkImageSpatialObject3SS

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSpatialObject3SS

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject3SS_cast(obj)

    def New(*args, **kargs):
        """New() -> itkImageSpatialObject3SS

        Create a new object of the class itkImageSpatialObject3SS and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkImageSpatialObject3SS.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkImageSpatialObject3SS.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkImageSpatialObject3SS.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkImageSpatialObject3SS in _itkImageSpatialObjectPython:
_itkImageSpatialObjectPython.itkImageSpatialObject3SS_swigregister(itkImageSpatialObject3SS)

def itkImageSpatialObject3UC_New():
    return itkImageSpatialObject3UC.New()

class itkImageSpatialObject3UC(itk.itkSpatialObjectBasePython.itkSpatialObject3):
    r"""Proxy of C++ itkImageSpatialObject3UC class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkImageSpatialObject3UC_Pointer"""
        return _itkImageSpatialObjectPython.itkImageSpatialObject3UC___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkImageSpatialObject3UC_Pointer"""
        return _itkImageSpatialObjectPython.itkImageSpatialObject3UC_Clone(self)

    def SetImage(self, image):
        r"""
        SetImage(self, image)

        Parameters
        ----------
        image: itkImageUC3 const *

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject3UC_SetImage(self, image)

    def GetImage(self):
        r"""GetImage(self) -> itkImageUC3"""
        return _itkImageSpatialObjectPython.itkImageSpatialObject3UC_GetImage(self)

    def ValueAtInObjectSpace(self, *args):
        r"""
        ValueAtInObjectSpace(self, point, value, depth=0, name="") -> bool

        Parameters
        ----------
        point: itkPointD3 const &
        value: double &
        depth: unsigned int
        name: std::string const &

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject3UC_ValueAtInObjectSpace(self, *args)

    def SetSliceNumber(self, *args):
        r"""
        SetSliceNumber(self, _arg)

        Parameters
        ----------
        _arg: itkIndex3

        SetSliceNumber(self, dimension, position)

        Parameters
        ----------
        dimension: unsigned int
        position: int

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject3UC_SetSliceNumber(self, *args)

    def GetSliceNumber(self, *args):
        r"""
        GetSliceNumber(self) -> itkIndex3
        GetSliceNumber(self, dimension) -> int

        Parameters
        ----------
        dimension: unsigned int

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject3UC_GetSliceNumber(self, *args)

    def SetInterpolator(self, interpolator):
        r"""
        SetInterpolator(self, interpolator)

        Parameters
        ----------
        interpolator: itkInterpolateImageFunctionIUC3D *

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject3UC_SetInterpolator(self, interpolator)

    def GetInterpolator(self):
        r"""GetInterpolator(self) -> itkInterpolateImageFunctionIUC3D"""
        return _itkImageSpatialObjectPython.itkImageSpatialObject3UC_GetInterpolator(self)
    __swig_destroy__ = _itkImageSpatialObjectPython.delete_itkImageSpatialObject3UC

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSpatialObject3UC

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSpatialObjectPython.itkImageSpatialObject3UC_cast(obj)

    def New(*args, **kargs):
        """New() -> itkImageSpatialObject3UC

        Create a new object of the class itkImageSpatialObject3UC and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkImageSpatialObject3UC.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkImageSpatialObject3UC.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkImageSpatialObject3UC.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkImageSpatialObject3UC in _itkImageSpatialObjectPython:
_itkImageSpatialObjectPython.itkImageSpatialObject3UC_swigregister(itkImageSpatialObject3UC)

